@@ -282,6 +282,8 @@ class Function(object):
 
     The default value for the ``msg`` when not provided via the
     constructor is ``Invalid value``.
+
+    The ``message`` parameter has been deprecated, use ``msg`` instead.
     """
     def __init__(self, function, msg=None, message=None):
         self.function = function
@@ -313,11 +315,13 @@ class Function(object):
 class Regex(object):
     """ Regular expression validator.
 
-        Initialize it with the string regular expression ``regex``
-        that will be compiled and matched against ``value`` when
-        validator is called. If ``msg`` is supplied, it will be the
-        error message to be used; otherwise, defaults to 'String does
-        not match expected pattern'.
+        Initialize it with the string regular expression ``regex`` that will
+        be compiled and matched against ``value`` when validator is called. It
+        uses Python's :py:func:`re.match`, which only matches at the beginning
+        of the string and not at the beginning of each line. To match the
+        entire string, enclose the regular expression with ``^`` and ``$``.
+        If ``msg`` is supplied, it will be the error message to be used;
+        otherwise, defaults to 'String does not match expected pattern'.
 
         The ``regex`` expression behaviour can be modified by specifying
         any ``flags`` value taken by ``re.compile``.
@@ -2116,12 +2120,9 @@ class _SchemaNode(object):
         """ Clone the schema node and return the clone.  All subnodes
         are also cloned recursively.  Attributes present in node
         dictionaries are preserved."""
-        children = [node.clone() for node in self.children]
-        cloned = self.__class__(self.typ, *children)
-
-        attributes = self.__dict__.copy()
-        attributes.pop('children', None)
-        cloned.__dict__.update(attributes)
+        cloned = self.__class__(self.typ)
+        cloned.__dict__.update(self.__dict__)
+        cloned.children = [node.clone() for node in self.children]
         return cloned
 
     def bind(self, **kw):
@@ -2144,7 +2145,10 @@ class _SchemaNode(object):
             v = getattr(self, k)
             if isinstance(v, deferred):
                 v = v(self, kw)
-                setattr(self, k, v)
+                if isinstance(v, SchemaNode):
+                    self[k] = v
+                else:
+                    setattr(self, k, v)
         if getattr(self, 'after_bind', None):
             self.after_bind(self, kw)
 
@@ -2238,7 +2242,7 @@ class _SchemaMeta(type):
                     value.title = name.replace('_', ' ').title()
                 nodes.append((value._order, value))
 
-        nodes.sort()
+        nodes.sort(key=lambda n: n[0])
         cls.__class_schema_nodes__ = [ n[1] for n in nodes ]
 
         # Combine all attrs from this class and its _SchemaNode superclasses.
@@ -2271,6 +2275,21 @@ class SequenceSchema(SchemaNode):
             raise Invalid(self,
                           'Sequence schemas must have exactly one child node')
 
+    def clone(self):
+        """ Clone the schema node and return the clone.  All subnodes
+        are also cloned recursively.  Attributes present in node
+        dictionaries are preserved."""
+
+        # Cloning a ``SequenceSchema`` doesn't work with ``_SchemaNode.clone``.
+
+        children = [node.clone() for node in self.children]
+        cloned = self.__class__(self.typ, *children)
+
+        attributes = self.__dict__.copy()
+        attributes.pop('children', None)
+        cloned.__dict__.update(attributes)
+        return cloned
+
 class deferred(object):
     """ A decorator which can be used to define deferred schema values
     (missing values, widgets, validators, etc.)"""
